pub struct SamplerProxy { /* private fields */ }Implementations
Sourceimpl SamplerProxy
impl SamplerProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.memory.sampler/Sampler.
Sourcepub fn take_event_stream(&self) -> SamplerEventStream
pub fn take_event_stream(&self) -> SamplerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn record_allocation(
&self,
payload: &SamplerRecordAllocationRequest,
) -> Result<(), Error>
pub fn record_allocation( &self, payload: &SamplerRecordAllocationRequest, ) -> Result<(), Error>
Record an allocation.
Sourcepub fn record_deallocation(
&self,
payload: &SamplerRecordDeallocationRequest,
) -> Result<(), Error>
pub fn record_deallocation( &self, payload: &SamplerRecordDeallocationRequest, ) -> Result<(), Error>
Record a deallocation.
Sourcepub fn set_process_info(
&self,
payload: &SamplerSetProcessInfoRequest,
) -> Result<(), Error>
pub fn set_process_info( &self, payload: &SamplerSetProcessInfoRequest, ) -> Result<(), Error>
Communicate relevant process information to facilitate symbolization.
If called several times, the last process_name prevails, but the
module_map is added to the existing map for the process. If a client
needs to send a module_map that does not fit in a single message, they
can split it and send it across several messages.