SamplerRecordDeallocationRequest

Struct SamplerRecordDeallocationRequest 

pub struct SamplerRecordDeallocationRequest {
    pub address: Option<u64>,
    pub stack_trace: Option<StackTrace>,
    /* private fields */
}

Fields

address: Option<u64>

Address of the deallocation, to uniquely identify it.

stack_trace: Option<StackTrace>

Stack frames collected at the deallocation point.

A client is free to truncate their stack traces to a size below the maximum size of a message that can be sent over the channel. If a client sends a StackTrace that causes to exceed the maximum size of the message, then the record will be dropped until RFC-0196 is implemented.